.. sadm documentation master file, created by
   sphinx-quickstart on Sun Jul 28 02:36:21 2019.

sadm documentation
==================

sysadmin/devops/deploy tools

.. toctree::
	:maxdepth: 2

	devel
